<?php
namespace WSCOMUN\SALT;
use WSCOMUN\WSComunFClient;
use Exception;
/**
 * Librera para que aplicaciones PHP/GVHidra puedan acceder al Web Service de Autenticacion
 *
 * @package		WSClientSALT
 * @author 		David Pascual <pascual_dav@externosgva.es>
 * @version		Release: @package_version@
 * @copyright 	Copyright (C) 2015 Generalitat Valenciana.
 * @license 	http://opensource.org/licenses/gpl-2.0.php GNU Public License v2.0
 * @link 		https://gvhidra.gva.es/redmine/projects/wscomun
 */
class WSClientSALT extends WSComunFClient
{

	/**
	 * Obtiene la traduccin del texto pasado como parmetro
	 *
	 * Los WS invocados pertenecen al servicio de traduccin SALT
	 * @param  	string	$texto	Texto a traducir en Castellano
	 * @return	string texto traducido
	 */
	public function castellanoValenciano ($texto)
	{
		$opcionesClienteWS = array (
				'soap_version' => SOAP_1_1, //SOAP 1.2
				'user_agent' => 'WSSSoapClient',
				'exceptions' => true,
				'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
				'trace' => self::$MYSOAPOP_TRACE
		);

		$clienteWS = null;
		try
		{
			$this->__clienteOn(self::KEYCLIENTE_SALT, true, $opcionesClienteWS);
			$clienteWS = $this->v_clienteWS[self::KEYCLIENTE_SALT];
			$textoTraducido = $clienteWS->castellanoValenciano($texto);
			if (is_object($textoTraducido))
			{
				return ($textoTraducido->texto);
			}
			else
			{
				return ($textoTraducido);
			}
		}
		catch (Exception $e)
		{
			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
				if (is_object($clienteWS))
				{
					$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
					$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
					$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
					$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
				}
				throw $e;
			}
			else
			{
				throw $e;
			}
		}
	}//castellanoValenciano


	/**
	 * Obtiene la traduccin del texto pasado como parmetro
	 *
	 * Los WS invocados pertenecen al servicio de traduccin SALT
	 * @param  	string	$texto	Texto a traducir en Valenciano
	 * @return	string texto traducido
	 */
	public function valencianoCastellano ($texto)
	{
		$opcionesClienteWS = array (
				'soap_version' => SOAP_1_1, //SOAP 1.2
				'user_agent' => 'WSSSoapClient',
				'exceptions' => true,
				'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
				'trace' => self::$MYSOAPOP_TRACE
		);

		try
		{
			$this->__clienteOn(self::KEYCLIENTE_SALT, true, $opcionesClienteWS);
			$clienteWS = $this->v_clienteWS[self::KEYCLIENTE_SALT];
			$textoTraducido = $clienteWS->valencianoCastellano($texto);
			if (is_object($textoTraducido))
			{
				return ($textoTraducido->texto);
			}
			else
			{
				return ($textoTraducido);
			}
		}
		catch (Exception $e)
		{
			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
				if (is_object($clienteWS))
				{
					$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
					$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
					$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
					$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
				}
				throw $e;
			}
			else
			{
				throw $e;
			}
		}
	}//valencianoCastellano

}

?>